@@ -111,6 +111,8 @@ MSG_FORWARD = b"FRWD"
 MSG_ABORT = b"ABT"
 MSG_PROGRESS = b"PROG"
 
+PROXY = "PROXY"
+
 # Session groups
 GROUP_RC = u"RocketChat"
 
@@ -477,3 +479,24 @@ ATTR_ANALOG_INPUT = "Analog input"
 ATTR_CHANNELS_CONFIGURATION = "Channels configuration"
 ATTR_NAME = "Name"
 ATTR_MEASUREMENT_STATUS = "Measurement status"
+ATTR_FIRMWARE = "Firmware version"
+ATTR_SENSORS_COUNT = "Sensors count"
+GROUP_MATERIALS = "Materials"
+ATTR_MATERIAL = "Material"
+ATTR_AUTO_Z = "Auto Z"
+ATTR_OUTPUT = "Output"
+GROUP_OUTPUTS = "Outputs"
+ATTR_PROCESS = "Process"
+GROUP_PROCESSES = "Processes"
+GROUP_USER_MESSAGES = "User messages"
+ATTR_USER_MESSAGE = "User message"
+ATTR_Z_RATIO = "Z ratio"
+ATTR_FUNDAMENTAL_FREQUENCY = "Fundamental freq"
+ATTR_AHARMONIC_FREQUENCY = "Aharmonic freq"
+ATTR_SENSOR_THICKNESS = "Sensor thickness"
+ATTR_CRYSTAL_LIFE = "Crystal life"
+ATTR_RAW_RATE = "Raw rate"
+ATTR_SHUTTER_STROKES = "Shutter strokes"
+ATTR_SHUTTER_OPEN = "Shutter open"
+ATTR_LAYER_THICKNESS = "Layer thickness"
+ATTR_ACTIVE_PROCESS = "Active process"
