@@ -7,6 +7,7 @@ from threading import Thread
 
 import numpy as np
 import serial
+from kamzik3.snippets.snippetsDecorators import expose_method
 from pint import UndefinedUnitError, DimensionalityError
 
 import kamzik3
@@ -972,3 +973,20 @@ class Device(Subject, YamlSerializable):
             self.handle_response_error(u"Response timeout")
             return False
         return True
+
+    @expose_method()
+    def server_disconnect(self):
+        """
+        This function serves just as a placeholder for
+        disconnect function, but visible to client.
+        """
+        self.disconnect()
+
+    @expose_method()
+    def server_reconnect(self):
+        """
+        This function serves just as a placeholder for
+        reconnect function, but visible to client.
+        """
+        self.reconnect()
+       
\ No newline at end of file
