@@ -111,7 +111,7 @@ class DeviceClient(Device):
             for attribute_id in self.attributes_sharing_map:
                 self._subscribe(attribute_id)
 
-    def _init_subscriber_thread(self):
+    def _init_subscriber_thread(self, host, port):
         """
         We are connected to the main server.
         Now we want to connect to the devices publisher.
@@ -125,7 +125,7 @@ class DeviceClient(Device):
         # Don't let socket linger after close
         # This is VERY IMPORTANT not to set to anything but 0
         self.subscriber_socket.setsockopt(zmq.LINGER, 0)
-        self.subscriber_socket.connect("tcp://{}:{}".format(self.host, kamzik3.session.config.get("publisher_port")))
+        self.subscriber_socket.connect("tcp://{}:{}".format(host, port))
         # Start separate Thread to read data from publisher
         self.subscription_thread = Thread(target=self._subscriber_thread)
         self.subscription_thread.start()
@@ -250,6 +250,10 @@ class DeviceClient(Device):
                             self._set(shared_attribute + [attribute_parts[-1]], data)
                     if token.startswith(self.subscribe_starts_with_list):
                         self._set(attribute_path, data)
+
+                # If publisher is defined, forward data to it
+                if kamzik3.session.publisher is not None:
+                    kamzik3.session.publisher.push_message(token, data)
             else:
                 raise DeviceClientError(
                     "Unrecognized token part {}. Token value was: {}".format(attribute_parts[1], token))
@@ -265,14 +269,20 @@ class DeviceClient(Device):
                 self.socket.send_multipart([INSTRUCTION_INIT, self.device_id.encode()])
                 status, token, response = self.handle_server_response()
             if status == RESPONSE_OK:
-                attributes, self.attributes_sharing_map, self.exposed_methods, self.qualified_name = json.loads(
+                allow_proxy = self.config.get("allow_proxy", True)
+                attributes, self.attributes_sharing_map, self.exposed_methods, self.qualified_name, device_proxy, device_publisher = json.loads(
                     response, object_hook=JsonKamzikHook)
+                if device_proxy is not False and allow_proxy:
+                    self.host, self.port = device_proxy
+                    self.close()
+                    self.reconnect()
+                    return False
                 self.initial_status = attributes[ATTR_STATUS][VALUE]
                 self._sync_attributes(attributes, self.attributes)
                 for method_name, attributes in self.exposed_methods[:]:
                     setattr(self, method_name,
                             lambda method_name=method_name, **kwargs: self.method(method_name, kwargs))
-                self._init_subscriber_thread()
+                self._init_subscriber_thread(*device_publisher)
                 return True
             else:
                 raise DeviceClientError(u"Failed to initialize device")
@@ -385,8 +395,6 @@ class DeviceClient(Device):
         This sets Device attribute.
         Use this function when You want to set attribute by tuple or list key.
         Example: Device.set((ATTR_STATUS, VALUE), STATUS_IDLE)
-        Attribute value is pushed into server if Device is connected on any.
-        To reduce amount of pushed attributes we check if value is different from previous one.
         :param attribute: tuple, list, str
         :param value: mixed
         :return: None
