@@ -1,9 +1,8 @@
-import time
-from threading import Thread
-
 import numpy as np
 import serial
+import time
 from bidict import frozenbidict
+from threading import Thread
 
 import kamzik3
 from kamzik3 import DeviceError, units
@@ -216,7 +215,7 @@ class DeviceGalilMotorChannel(DeviceChannel):
                               set_function=self.set_amplifier_gain)
         self.create_attribute(ATTR_MOTOR_TYPE, default_type=MOTOR_TYPES.keys(), set_function=self.set_motor_type)
         self.create_attribute(ATTR_VELOCITY, default_type=np.float, min_value=-15e6, max_value=15e6, unit=u"steps/sec",
-                              set_function=self.set_velocity)
+                              set_function=self.set_velocity, decimals=3)
         self.create_attribute(ATTR_STEP_DRIVE_RESOLUTION, default_type=np.uint64, max_value=15e6, unit=u"ustep",
                               set_function=self.set_step_drive_resolution)
         self.create_attribute(ATTR_BACKLASH_DISTANCE, default_value=0, default_type=np.float64, readonly=False,
@@ -231,10 +230,10 @@ class DeviceGalilMotorChannel(DeviceChannel):
         self.create_attribute(FLAG_REVERSE_LIMIT_INACTIVE, default_type=np.bool, readonly=True)
         self.create_attribute(ATTR_LOW_CURRENT_STEPPER_MODE, default_type=np.uint32, max_value=32767,
                               set_function=self.set_low_current_stepper_mode)
-        self.create_attribute(ATTR_ACCELERATION, default_type=np.uint64, min_value=1024, max_value=1073740800,
-                              set_function=self.set_acceleration)
-        self.create_attribute(ATTR_DECELERATION, default_type=np.uint64, min_value=1024, max_value=1073740800,
-                              set_function=self.set_deceleration)
+        self.create_attribute(ATTR_ACCELERATION, default_type=np.float, min_value=1024, max_value=1073740800,
+                              set_function=self.set_acceleration, unit="steps/sec^2", decimals=3)
+        self.create_attribute(ATTR_DECELERATION, default_type=np.float, min_value=1024, max_value=1073740800,
+                              set_function=self.set_deceleration, unit="steps/sec^2", decimals=3)
         self.create_attribute(ATTR_POSITION, default_type=np.float64, unit=u"counts", set_function=self._move_absolute,
                               set_value_when_set_function=False)
         self.create_attribute(ATTR_HOMING_METHOD, default_value=u"Limit based", default_type=HOMING_METHODS.keys())
@@ -252,6 +251,7 @@ class DeviceGalilMotorChannel(DeviceChannel):
         self.create_attribute(ATTR_REFERENCED, default_value=False, default_type=np.bool, readonly=True)
         self.create_attribute(ATTR_REFERENCE_STEPS_BACK, default_value=40, default_type=np.uint32, min_value=1,
                               unit=u"steps")
+        self.create_attribute(ATTR_STEPS_PER_REVOLUTION, default_value=1, default_type=np.uint32)
 
     def handle_configuration(self):
         if self.configured:
@@ -284,6 +284,10 @@ class DeviceGalilMotorChannel(DeviceChannel):
 
             if attribute == ATTR_VELOCITY:
                 value /= self.get_raw_value(ATTR_STEP_DRIVE_RESOLUTION)
+            elif attribute == ATTR_ACCELERATION:
+                value /= self.get_raw_value(ATTR_STEP_DRIVE_RESOLUTION)
+            elif attribute == ATTR_DECELERATION:
+                value /= self.get_raw_value(ATTR_STEP_DRIVE_RESOLUTION)
             elif attribute == ATTR_STATUS:
                 if self.get_value(FLAG_REFERENCING):
                     value = STATUS_BUSY
@@ -345,9 +349,11 @@ class DeviceGalilMotorChannel(DeviceChannel):
         return self.command(u"LD{}={};".format(self.acronym, LIMIT_SWITCHES_MODE.get(value)), callback, with_token=True)
 
     def set_acceleration(self, value, callback=None):
+        value = value * self.get_value(ATTR_STEP_DRIVE_RESOLUTION)
         return self.command(u"AC{}={};".format(self.acronym, int(value)), callback, with_token=True)
 
     def set_deceleration(self, value, callback=None):
+        value = value * self.get_value(ATTR_STEP_DRIVE_RESOLUTION)
         return self.command(u"DC{}={};".format(self.acronym, int(value)), callback, with_token=True)
 
     def set_motor_type(self, motor_type, callback=None):
