@@ -23,7 +23,7 @@ from kamzik3.snippets.snippetsControlLoops import control_asyncore_loop, control
 from kamzik3.snippets.snippetsDecorators import expose_method
 from kamzik3.snippets.snippetsTimer import CallbackTimer
 from kamzik3.snippets.snippetsYaml import YamlDumper, YamlConfigSerializer
-
+from multiprocessing import Process
 
 class DeviceSession(Device):
     LOG_DEVICE_OUTPUT_FILE = u"devices.log"
@@ -469,3 +469,20 @@ class DeviceSession(Device):
                     shutil.rmtree(file_path)
             except Exception as e:
                 self.logger.error('Failed to delete %s. Reason: %s' % (file_path, e))
+
+def server_process(conf, stop_event):
+    def _process(conf, stop_event):
+        import kamzik3
+        import yaml
+        from time import sleep
+        with open(conf, "r") as configFile:
+            yaml.load(configFile, Loader=yaml.Loader)
+
+        # Start control loop for devices specified in configuration file
+        kamzik3.session.set_config(conf)
+        kamzik3.session.start_control_loops()
+        while not stop_event.is_set():
+            sleep(1)
+        kamzik3.session.stop()
+
+    return Process(target=_process, args=(conf, stop_event))
