@@ -19,7 +19,7 @@ class DeviceSocket(asynchat.async_chat, Device):
         self.asyncore_loop = control_asyncore_loop
         self.host = host
         self.port = port
-        self.send_lock = Lock()
+        self.send_lock = RLock()
         asynchat.async_chat.__init__(self)
         self.create_socket(socket.AF_INET, socket.SOCK_STREAM)
         self.socket.setblocking(False)
