@@ -2,6 +2,8 @@ import json
 import logging
 from threading import Thread
 
+from kamzik3.devices.deviceClient import DeviceClient
+
 import kamzik3
 from kamzik3 import CommandFormatException, DeviceServerError, DeviceError
 from kamzik3.constants import *
@@ -59,12 +61,15 @@ class DeviceWorker(Worker, Thread):
                 if device is None:
                     raise DeviceServerError(
                         "Device {} is not registered on the server or publisher is not ready".format(device_id))
-                elif not device.in_statuses(READY_DEVICE_STATUSES):
-                    raise DeviceServerError("Device is not ready")
                 else:
+                    device_proxy = False
+                    if isinstance(device, DeviceClient):
+                        device_proxy = (device.host, device.port)
+                    device_publisher = (kamzik3.session.publisher.host,
+                                        kamzik3.session.publisher.port)
                     response = json.dumps(
                         (device.attributes, device.attributes_sharing_map,
-                         device.exposed_methods, device.qualified_name), cls=JsonKamzikEncoder,
+                         device.exposed_methods, device.qualified_name, device_proxy, device_publisher), cls=JsonKamzikEncoder,
                         ensure_ascii=True)
                     status, token = RESPONSE_OK, 0
             # None of above, request not implemented
