@@ -21,10 +21,11 @@ class ScanAttributeWidget(Ui_Form, MacroWidget):
     attribute = None
     debug_widget = None
 
-    def __init__(self, title=None, config=None, parent=None):
-        MacroWidget.__init__(self, parent)
+    def __init__(self, title=None, config=None, user_mode=MODE_SIMPLE, parent=None):
+        MacroWidget.__init__(self, user_mode=user_mode, parent=parent)
         self.config = config
         self.title = title
+        self.macro_mode = 0
         if self.config is None:
             self.config = {}
         self.setupUi(self)
@@ -71,7 +72,7 @@ class ScanAttributeWidget(Ui_Form, MacroWidget):
         self.button_group.addButton(self.step_size_lock_button)
         self.button_group.addButton(self.field_size_lock_button)
 
-        self.spacer = self.gridLayout.itemAtPosition(5, 0)
+        self.spacer = self.gridLayout.itemAtPosition(6, 0)
         self.set_title(self.title)
         self._init_device_list()
         self._init_scanner_list()
@@ -84,10 +85,13 @@ class ScanAttributeWidget(Ui_Form, MacroWidget):
 
     def _init_template_settings(self):
         if not self.config.get(CFG_TEMPLATE, False):
-            self.label_settings.hide()
-            self.widget_settings.hide()
+            if self.user_mode != MODE_ALL:
+                self.label_settings.hide()
+                self.widget_settings.hide()
             self.label_scanner.hide()
             self.combobox_scanner.hide()
+            self.label_warning.hide()
+            self.combobox_warning.hide()
 
     def _init_device_list(self):
         self.combobox_device.blockSignals(True)
@@ -171,6 +175,19 @@ class ScanAttributeWidget(Ui_Form, MacroWidget):
         self.field_size_set_widget.setParent(None)
         self.step_size_set_widget.setParent(None)
         self.total_steps_set_widget.setParent(None)
+        self.total_steps_set_widget.setParent(None)
+
+        if self.user_mode == MODE_ALL:
+            self.label_settings.show()
+            self.widget_settings.show()
+            self.checkbox_log.setChecked(self.config.get("trigger_log", True))
+            self.checkbox_as_step.setChecked(self.config.get("as_step", False))
+            self.checkbox_return_back.setChecked(self.config.get("return_back", True))
+            self.checkbox_bidirectional.setChecked(self.config.get("bidirectional", False))
+        else:
+            self.label_settings.hide()
+            self.widget_settings.hide()
+
         if attribute in ("", "None", None):
             # Don't show any widget if attribute is empty
             self.attribute = None
@@ -192,24 +209,34 @@ class ScanAttributeWidget(Ui_Form, MacroWidget):
                 row += 1
                 self.macro_widgets.append(self._show_field_size_widget(row, user_unit))
             row += 1
-            self.macro_widgets.append(self._show_negative_tolerance_widget(row, user_unit))
-            row += 1
-            self.macro_widgets.append(self._show_positive_tolerance_widget(row, user_unit))
-            row += 1
-            self.macro_widgets.append(self._show_random_deviation_widget(row))
-            row += 1
-            self.macro_widgets.append(self._show_wait_after_widget(row))
-            row += 1
-            self.macro_widgets.append(self._show_repeat_widget(row))
-            row += 1
-            self.macro_widgets.append(self._show_retry_widget(row))
-            row += 1
+
+            if self.user_mode in (MODE_ALL, MODE_EXTENDED):
+                self.macro_widgets.append(self._show_negative_tolerance_widget(row, user_unit))
+                row += 1
+                self.macro_widgets.append(self._show_positive_tolerance_widget(row, user_unit))
+                row += 1
+                self.macro_widgets.append(self._show_random_deviation_widget(row))
+                row += 1
+                self.macro_widgets.append(self._show_wait_after_widget(row))
+                row += 1
+                self.macro_widgets.append(self._show_repeat_widget(row))
+                row += 1
+                self.macro_widgets.append(self._show_retry_widget(row))
+                row += 1
+                self.macro_widgets.append(self._show_timeout(row))
+                row += 1
+                self.macro_widgets.append(self._show_on_warning_widget(row))
+                row += 1
 
             if self.config.get("scanner", "None") != "None":
                 scanner = kamzik3.session.get_device(self.config["scanner"])
                 try:
                     scanner_attributes = scanner.get_scanner_attributes()
                     for attribute in scanner_attributes:
+                        if attribute == "timeout" and self.user_mode is MODE_SIMPLE:
+                            self.macro_widgets.append(self._show_timeout(row))
+                            row += 1
+                            continue
                         self.macro_widgets.append(
                             self._show_method_attribute_widget(attribute,
                                                                scanner.get_attribute(attribute).attribute_copy(),
@@ -425,12 +452,16 @@ class ScanAttributeWidget(Ui_Form, MacroWidget):
                 values["end_point"] = self.attribute.value() + half_field_size
             step_attributes = {
                 "device_id": self.combobox_device.currentText(),
-                "wait_after": values["wait_after"],
+                "wait_after": units.Quantity(self.config.get("wait_after", "0s") if self.user_mode == MODE_SIMPLE else values["wait_after"]).to("s"),
                 "attribute": self.config.get("attribute").split(u" # "),
-                "negative_tolerance": values["positive_tolerance"],
-                "positive_tolerance": values["negative_tolerance"],
-                "retry_count": int(values["retry_count"].m),
-                "trigger_log": self.config.get("trigger_log", True)
+                "negative_tolerance": self.attribute.negative_tolerance() if self.user_mode == MODE_SIMPLE else (
+                values["negative_tolerance"] if self.attribute.numerical else None),
+                "positive_tolerance": self.attribute.positive_tolerance() if self.user_mode == MODE_SIMPLE else (
+                values["positive_tolerance"] if self.attribute.numerical else None),
+                "retry_count": self.config.get("retry_count", 0) if self.user_mode == MODE_SIMPLE else int(values["retry_count"].m),
+                "trigger_log": self.config.get("trigger_log", True) if self.user_mode == MODE_SIMPLE else self.checkbox_log.isChecked(),
+                "on_warning": self.config.get("on_warning", "Abort macro") if self.user_mode == MODE_SIMPLE else values["on_warning"],
+                "timeout": units.Quantity(self.config.get("timeout", "0s") if self.user_mode == MODE_SIMPLE else values["timeout"]).to("s")
             }
             if values["total_steps"] <= 0:
                 raise ValueError("Total steps for {} has to be greater than zero.".format(self.title))
@@ -443,19 +474,25 @@ class ScanAttributeWidget(Ui_Form, MacroWidget):
                 scanner_device = kamzik3.session.get_device(scanner)
                 for attribute in scanner_device.get_scanner_attributes():
                     scanner_attributes[attribute] = self.macro_inputs[attribute].get_attribute_value()
-            if self.config.get("as_step", False):
-                step_attributes["repeat_count"] = values["repeat"]
+
+            as_step = self.checkbox_as_step.isChecked() if self.user_mode == MODE_ALL else self.config.get("as_step", False)
+            bidirectional = self.checkbox_bidirectional.isChecked() if self.user_mode == MODE_ALL else self.config.get("bidirectional", False)
+            return_back = self.checkbox_return_back.isChecked() if self.user_mode == MODE_ALL else self.config.get("return_back", True)
+
+            random_deviation = units.Quantity(self.config.get("random_deviation", "0.0 percent") if self.user_mode == MODE_SIMPLE else values["random_deviation"]).to("percent")
+            repeat_count = self.config.get("repeat", 0) if self.user_mode == MODE_SIMPLE else values["repeat"]
+            if as_step:
+                step_attributes["repeat_count"] = repeat_count
                 scan = Scan("Scan", values["start_point"], values["end_point"], int(values["total_steps"].m),
-                            step_class=StepDeviceAttributeNumerical, step_attributes=step_attributes, as_step=True,
-                            bidirectional=self.config.get("bidirectional", False), scanner=scanner,
-                            scanner_attributes=scanner_attributes, return_back=self.config.get("return_back", True))
+                            step_class=StepDeviceAttributeNumerical, step_attributes=step_attributes,
+                            as_step=as_step, bidirectional=bidirectional,
+                            scanner=scanner, scanner_attributes=scanner_attributes, return_back=return_back)
             else:
-                scan = Scan("Scan", values["start_point"], values["end_point"], int(values["total_steps"].m),
-                            repeat_count=values["repeat"], random_deviation=values["random_deviation"],
-                            step_class=StepDeviceAttributeNumerical,
-                            step_attributes=step_attributes, as_step=False,
-                            bidirectional=self.config.get("bidirectional", False), scanner=scanner,
-                            scanner_attributes=scanner_attributes, return_back=self.config.get("return_back", True))
+                scan = Scan("Scan", values["start_point"], values["end_point"],
+                            int(values["total_steps"].m), repeat_count=repeat_count,
+                            random_deviation=random_deviation, step_class=StepDeviceAttributeNumerical,
+                            step_attributes=step_attributes, as_step=as_step, bidirectional=bidirectional,
+                            scanner=scanner, scanner_attributes=scanner_attributes, return_back=return_back)
             return scan
         except KeyError:
             if self.combobox_device.currentText() == "None":
@@ -477,9 +514,9 @@ class ScanAttributeWidget(Ui_Form, MacroWidget):
             "trigger_log": self.checkbox_log.isChecked(),
             "as_step": self.checkbox_as_step.isChecked(),
             "scanner": self.combobox_scanner.currentText(),
-            "defaults": self.checkbox_defaults.isChecked(),
             "bidirectional": self.checkbox_bidirectional.isChecked(),
-            "return_back": self.checkbox_return_back.isChecked()
+            "return_back": self.checkbox_return_back.isChecked(),
+            "on_warning": self.combobox_warning.currentText(),
         }
 
     def show_debug_widget(self):
@@ -496,3 +533,15 @@ class ScanAttributeWidget(Ui_Form, MacroWidget):
             self.debug_widget = DeviceDebugWidget(self.device)
 
         show_centralized_top(self.debug_widget)
+
+    def set_simple_mode(self):
+        MacroWidget.set_simple_mode(self)
+        self.attribute_selected(self.config.get("attribute"))
+
+    def set_extended_mode(self):
+        MacroWidget.set_extended_mode(self)
+        self.attribute_selected(self.config.get("attribute"))
+
+    def set_all_mode(self):
+        MacroWidget.set_all_mode(self)
+        self.attribute_selected(self.config.get("attribute"))
